mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Heiko Bauke <heiko.bauke@snafu.de>
To: linux-kernel@vger.kernel.org
Subject: [PATCH] net: plusb.c
Date: Sun, 12 Sep 2010 17:27:14 +0200	[thread overview]
Message-ID: <20100912172714.3f4dd401@tron.localdomain> (raw)

[-- Attachment #1: Type: text/plain, Size: 402 bytes --]

Dear Kernel-Developers,

note that the plusb.c driver for Prolific PL-2301/2302 USB Host to Host
Link Driver may be used also for Prolific PL-2501 devices if a rather
trivial patch is applied to plusb.c.


	Regards,

	Heiko



-- 
--  Cluster Computing @ http://www.clustercomputing.de
-- Number Crunch Blog @ http://numbercrunch.de
--        Heiko Bauke @ http://www.mpi-hd.mpg.de/personalhomes/bauke

[-- Attachment #2: plusb.patch --]
[-- Type: text/x-patch, Size: 1531 bytes --]

diff -urN linux_orig/drivers/net/usb/plusb.c linux_new/drivers/net/usb/plusb.c
--- linux_orig/drivers/net/usb/plusb.c	2010-09-12 17:07:08.377086065 +0200
+++ linux_new/drivers/net/usb/plusb.c	2010-09-12 17:10:06.088880446 +0200
@@ -1,5 +1,5 @@
 /*
  * PL-2301/2302 USB host-to-host link cables
  * Copyright (C) 2000-2005 by David Brownell
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,7 @@
 
 
 /*
- * Prolific PL-2301/PL-2302 driver ... http://www.prolifictech.com
+ * Prolific PL-2301/2302/2501 driver ... http://www.prolifictech.com
  *
  * The protocol and handshaking used here should be bug-compatible
  * with the Linux 2.2 "plusb" driver, by Deti Fliegl.
@@ -95,7 +95,7 @@
 }
 
 static const struct driver_info	prolific_info = {
-	.description =	"Prolific PL-2301/PL-2302",
+	.description =	"Prolific PL-2301/2302/2501",
 	.flags =	FLAG_NO_SETINT,
 		/* some PL-2302 versions seem to fail usb_set_interface() */
 	.reset =	pl_reset,
@@ -117,6 +117,9 @@
 }, {
 	USB_DEVICE(0x067b, 0x0001),	// PL-2302
 	.driver_info =	(unsigned long) &prolific_info,
+}, {
+	USB_DEVICE(0x067b, 0x2501),	// PL-2501
+	.driver_info =	(unsigned long) &prolific_info,
 },
 
 	{ },		// END
@@ -145,5 +148,5 @@
 module_exit(plusb_exit);
 
 MODULE_AUTHOR("David Brownell");
-MODULE_DESCRIPTION("Prolific PL-2301/2302 USB Host to Host Link Driver");
+MODULE_DESCRIPTION("Prolific PL-2301/2302/2501 USB Host to Host Link Driver");
 MODULE_LICENSE("GPL");

                 reply	other threads:[~2010-09-12 15:40 UTC|newest]
@@ -1,5 +1,5 @@
 /*
- * PL-2301/2302 USB host-to-host link cables
+ * PL-2301/2302/2501 USB host-to-host link cables
  * Copyright (C) 2000-2005 by David Brownell
  *

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20100912172714.3f4dd401@tron.localdomain \
    --to=heiko.bauke@snafu.de \
    --cc=linux-kernel@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®